
.. _table_api:

Table objects
================

Table objects are constructed using the ``add_table()`` method on |Document|.


.. currentmodule:: docx.table


|Table| objects
---------------

.. autoclass:: Table
   :members:
   :exclude-members: table


|_Cell| objects
------------------------

.. autoclass:: _Cell
   :members:


|_Row| objects
--------------

.. autoclass:: _Row
   :members:


|_Column| objects
-----------------

.. autoclass:: _Column
   :members:


|_Rows| objects
---------------

.. autoclass:: _Rows
   :members:


|_Columns| objects
------------------

.. autoclass:: _Columns
   :members:
